@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::PadrePlugin;
 BEGIN {
-  $Dist::Zilla::PluginBundle::PadrePlugin::VERSION = '0.06';
+  $Dist::Zilla::PluginBundle::PadrePlugin::VERSION = '0.07';
 }
 
 # ABSTRACT: Dist::Zilla plugin bundle for PadrePlugin
@@ -15,7 +15,6 @@ use Dist::Zilla::PluginBundle::Basic;
 use Dist::Zilla::Plugin::CheckChangeLog;
 use Dist::Zilla::Plugin::CheckChangesTests;
 use Dist::Zilla::Plugin::CompileTests;
-use Dist::Zilla::Plugin::LoadTests;
 use Dist::Zilla::Plugin::EOLTests;
 use Dist::Zilla::Plugin::PodWeaver;
 use Dist::Zilla::Plugin::PkgVersion;
@@ -66,9 +65,7 @@ sub configure {
 	# Start adding plugins
 	$self->add_plugins(qw( CheckChangeLog CheckChangesTests ));
 
-	my $needs_display = [ 'needs_display' => '1', ];
-	$self->add_plugins( [ 'CompileTests' => $needs_display ] );
-	$self->add_plugins( [ 'LoadTests'    => $needs_display ] );
+	$self->add_plugins( [ 'CompileTests' => [ 'needs_display' => '1', ] ] );
 
 	$self->add_plugins(qw(EOLTests PkgVersion PodWeaver));
 
@@ -106,7 +103,7 @@ sub configure {
 		[   Prereqs => 'LocaleMsgfmtDeps' => {
 				-phase           => 'test',
 				-type            => 'requires',
-				'Locale::Msgfmt' => '0.14'
+				'Locale::Msgfmt' => '0.15'
 			}
 		],
 	);
@@ -139,7 +136,7 @@ Dist::Zilla::PluginBundle::PadrePlugin - Dist::Zilla plugin bundle for PadrePlug
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -158,7 +155,6 @@ is equivalent to:
 	[CheckChangeLog]
 	[CheckChangesTests]
 	[CompileTests]
-	[LoadTests]
 	[EOLTests]
 	[PodWeaver]
 	[PkgVersion]
